YARP ChangeLog                                                      {#changelog}
==============

This page lists the main changes introduced in YARP at each release.

## YARP 3.6 Series                                            {#yarp_3_6_series}
 * \subpage master

## YARP 3.5 Series                                            {#yarp_3_5_series}
* \subpage yarp_3_5
* \subpage v3_5_0

## YARP 3.4 Series                                            {#yarp_3_4_series}
* \subpage v3_4_6
* \subpage v3_4_5
* \subpage v3_4_4
* \subpage v3_4_3
* \subpage v3_4_2
* \subpage v3_4_1
* \subpage v3_4_0

## YARP 3.3 Series                                            {#yarp_3_3_series}
* \subpage v3_3_3
* \subpage v3_3_2
* \subpage v3_3_1
* \subpage v3_3_0

## YARP 3.2 Series                                            {#yarp_3_2_series}
* \subpage v3_2_2
* \subpage v3_2_1
* \subpage v3_2_0

## YARP 3.1 Series                                            {#yarp_3_1_series}
* \subpage v3_1_2
* \subpage v3_1_1
* \subpage v3_1_0

## YARP 3.0 Series                                            {#yarp_3_0_series}
* \subpage v3_0_1
* \subpage v3_0_0

## YARP 2.3.72 Series                                      {#yarp_2_3_72_series}
* \subpage v2_3_72_1
* \subpage v2_3_72

## YARP 2.3.70 Series                                      {#yarp_2_3_70_series}
* \subpage v2_3_70_2
* \subpage v2_3_70_1
* \subpage v2_3_70

## YARP 2.3.68 Series                                      {#yarp_2_3_68_series}
* \subpage v2_3_68_1
* \subpage v2_3_68

## YARP 2.3.66 Series                                      {#yarp_2_3_66_series}
* \subpage v2_3_66_2
* \subpage v2_3_66_1
* \subpage v2_3_66

## YARP 2.3.65 Series                                      {#yarp_2_3_65_series}
* \subpage v2_3_65

## Older YARP Releases                                    {#yarp_older_releases}
* \subpage v2_3_64
* \subpage v2_3_63
* \subpage v2_3_62
* \subpage v2_3_61
* \subpage v2_3_60
* \subpage v2_3_22
* \subpage v2_3_21
* \subpage v2_3_20_1
* \subpage v2_3_20
* \subpage v2_3_19
* \subpage v2_3_15
* \subpage v2_3_14
* \subpage v2_3_12
* \subpage v2_3_10
* \subpage v2_3_9
* \subpage v2_3_8
* \subpage v2_3_7
* \subpage v2_3_6
* \subpage v2_3_5
* \subpage v2_3_4
* \subpage v2_3_3
* \subpage v2_3_2
* \subpage v2_3_1
* \subpage v2_3_0
* \subpage v2_2_7
* \subpage v2_2_6
* \subpage v2_2_5
* \subpage v2_2_4
* \subpage v2_2_3
* \subpage v2_2_2
* \subpage v2_2_1
* \subpage v2_2_0
* \subpage v2_1_9
* \subpage v2_1_8
* \subpage v2_1_7
* \subpage v2_1_6
* \subpage v2_1_5
* \subpage v2_1_4
* \subpage v2_1_3
* \subpage v2_1_0
* \subpage v2_0_4
